You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@empire-db.apache.org by do...@apache.org on 2020/01/13 21:54:12 UTC

[empire-db] branch master updated: EMPIREDB-320 fix for comment and logging

This is an automated email from the ASF dual-hosted git repository.

doebele pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/empire-db.git


The following commit(s) were added to refs/heads/master by this push:
     new 7f0cc7d  EMPIREDB-320 fix for comment and logging
7f0cc7d is described below

commit 7f0cc7d3aac2602d5ae96dcc903ce965c29fa2a7
Author: Rainer Döbele <do...@apache.org>
AuthorDate: Mon Jan 13 22:54:08 2020 +0100

    EMPIREDB-320
    fix for comment and logging
---
 .../src/main/java/org/apache/empire/jsf2/components/ControlTag.java   | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/empire-db-jsf2/src/main/java/org/apache/empire/jsf2/components/ControlTag.java b/empire-db-jsf2/src/main/java/org/apache/empire/jsf2/components/ControlTag.java
index e42c39c..8c1698a 100644
--- a/empire-db-jsf2/src/main/java/org/apache/empire/jsf2/components/ControlTag.java
+++ b/empire-db-jsf2/src/main/java/org/apache/empire/jsf2/components/ControlTag.java
@@ -688,8 +688,8 @@ public class ControlTag extends UIInput implements NamingContainer
                 log.debug("Changing UIInput readOnly state for {} to {}", helper.getColumnName(), renderInput);
         }
         else
-        {   // Must have at least two children, one for Input and one for Output
-            log.warn("Control-Tag does not have separate Input and Output components");
+        {   // Must have at least two children, for label and input
+            log.warn("Control-Tag does not have separate Label and Input components");
         }
     }